@@ -29,6 +29,7 @@ Dependencies:
 - requests_unixsocket: For making HTTP requests over UNIX domain sockets.
 """
 
+import json
 import os
 from pathlib import Path
 import random
@@ -37,6 +38,7 @@ from dataclasses import dataclass, field
 from urllib.parse import quote
 from typing import BinaryIO, Dict, List, Optional, Set, Union
 import boto3  # type: ignore
+import sseclient
 from boto3.s3.transfer import TransferConfig
 import requests  # type: ignore
 import requests_unixsocket  # type: ignore
@@ -575,9 +577,22 @@ def _download_single_file_by_cached(
             "token": token,
             "endpoint": endpoint,
         },
+        stream=True,
         timeout=3600,
     )
-    blob_path = r.json().get("cachedFilePath")
+    blob_path = ""
+    if r.headers["Content-Type"] == "text/event-stream":
+        # handle event stream
+        sse_r = sseclient.SSEClient(r)
+        for event in sse_r.events():
+            msg = json.loads(event.data)
+            if msg["cached"]:
+                blob_path = msg["cachedFilePath"]
+                break
+            else:
+                print_percent(str(slk_path), msg["written"], msg["total"])
+    else:
+        blob_path = r.json().get("cachedFilePath")
     logger.debug("cached blob file path: %s", blob_path)
     slk_path.parent.mkdir(parents=True, exist_ok=True)
     slk_path.symlink_to(blob_path)
